@@ -45,24 +45,11 @@ from keras.utils.generic_utils import deserialize_keras_object
 np.random.seed(7)
 
 
-# In[2]:
 
 
 from keras import activations
 
 
-# In[3]:
-
-
-p1=1
-p2=2
-p3=6
-p4=24
-p5=120
-p6=720
-
-
-# In[4]:
 
 
 def create_model_classic(active1,active2):
@@ -77,7 +64,6 @@ def create_model_classic(active1,active2):
     return model
 
 
-# In[5]:
 
 
 #Defining New Activation functions
@@ -144,27 +130,27 @@ get_custom_objects().update({'S_X_6': Activation(S_X_6)})
 #Defining New Activation functions
 ############################################################################
 def C_a_X_1(x):
-    return (K.pow(x,1))/p1
+    return (K.pow(x,1))/1
 get_custom_objects().update({'C_a_X_1': Activation(C_a_X_1)})
 ############################################################################
 def C_a_X_2(x):
-    return ((2*K.pow(x,2))-1)/p2
+    return ((2*K.pow(x,2))-1)/2
 get_custom_objects().update({'C_a_X_2': Activation(C_a_X_2)})
 ############################################################################
 def C_a_X_3(x):
-    return ((4*K.pow(x,3))-(3*x))/p3
+    return ((4*K.pow(x,3))-(3*x))/6
 get_custom_objects().update({'C_a_X_3': Activation(C_a_X_3)})
 ############################################################################
 def C_a_X_4(x):
-    return ((8*K.pow(x,4))-(8*K.pow(x,2))+1)/p4
+    return ((8*K.pow(x,4))-(8*K.pow(x,2))+1)/24
 get_custom_objects().update({'C_a_X_4': Activation(C_a_X_4)})
 ############################################################################
 def C_a_X_5(x):
-    return ((16*K.pow(x,5))-(20*K.pow(x,3))+(5*x))/p5
+    return ((16*K.pow(x,5))-(20*K.pow(x,3))+(5*x))/120
 get_custom_objects().update({'C_a_X_5': Activation(C_a_X_5)})
 ############################################################################
 def C_a_X_6(x):
-    return ((32*K.pow(x,6))-(48*K.pow(x,4))+(18*K.pow(x,2))-1)/p6
+    return ((32*K.pow(x,6))-(48*K.pow(x,4))+(18*K.pow(x,2))-1)/720
 get_custom_objects().update({'C_a_X_6': Activation(C_a_X_6)})
 
 
@@ -174,27 +160,27 @@ get_custom_objects().update({'C_a_X_6': Activation(C_a_X_6)})
 #Defining New Activation functions
 ############################################################################
 def C_b_X_1(x):
-    return (2*K.pow(x,1))/p1
+    return (2*K.pow(x,1))/1
 get_custom_objects().update({'C_b_X_1': Activation(C_b_X_1)})
 ############################################################################
 def C_b_X_2(x):
-    return ((4*K.pow(x,2))-1)/p2
+    return ((4*K.pow(x,2))-1)/2
 get_custom_objects().update({'C_b_X_2': Activation(C_b_X_2)})
 ############################################################################
 def C_b_X_3(x):
-    return ((8*K.pow(x,3))-(4*x))/p3
+    return ((8*K.pow(x,3))-(4*x))/6
 get_custom_objects().update({'C_b_X_3': Activation(C_b_X_3)})
 ############################################################################
 def C_b_X_4(x):
-    return ((16*K.pow(x,4))-(12*K.pow(x,2))+1)/p4
+    return ((16*K.pow(x,4))-(12*K.pow(x,2))+1)/24
 get_custom_objects().update({'C_b_X_4': Activation(C_b_X_4)})
 ############################################################################
 def C_b_X_5(x):
-    return ((32*K.pow(x,5))-(32*K.pow(x,3))+6*x)/p5
+    return ((32*K.pow(x,5))-(32*K.pow(x,3))+6*x)/120
 get_custom_objects().update({'C_b_X_5': Activation(C_b_X_5)})
 ############################################################################
 def C_b_X_6(x):
-    return ((64*K.pow(x,4))-(80*K.pow(x,4))+(24*K.pow(x,2))-1)/p6
+    return ((64*K.pow(x,4))-(80*K.pow(x,4))+(24*K.pow(x,2))-1)/720
 get_custom_objects().update({'C_b_X_6': Activation(C_b_X_6)})
 
 
@@ -204,27 +190,27 @@ get_custom_objects().update({'C_b_X_6': Activation(C_b_X_6)})
 #Defining New Activation functions
 ############################################################################
 def H_X_1(x):
-    return (2*K.pow(x,1))/p1
+    return (2*K.pow(x,1))/1
 get_custom_objects().update({'H_X_1': Activation(H_X_1)})
 ############################################################################
 def H_X_2(x):
-    return ((4*K.pow(x,2))-2)/p2
+    return ((4*K.pow(x,2))-2)/2
 get_custom_objects().update({'H_X_2': Activation(H_X_2)})
 ############################################################################
 def H_X_3(x):
-    return ((8*K.pow(x,3))-(12*x))/p3
+    return ((8*K.pow(x,3))-(12*x))/6
 get_custom_objects().update({'H_X_3': Activation(H_X_3)})
 ############################################################################
 def H_X_4(x):
-    return ((16*K.pow(x,4))-(48*K.pow(x,2))+12)/p4
+    return ((16*K.pow(x,4))-(48*K.pow(x,2))+12)/24
 get_custom_objects().update({'H_X_4': Activation(H_X_4)})
 ############################################################################
 def H_X_5(x):
-    return ((32*K.pow(x,5))-(160*K.pow(x,3))+120*x)/p5
+    return ((32*K.pow(x,5))-(160*K.pow(x,3))+120*x)/120
 get_custom_objects().update({'H_X_5': Activation(H_X_5)})
 ############################################################################
 def H_X_6(x):
-    return ((64*K.pow(x,6))-(480*K.pow(x,4))+(720*K.pow(x,2))-120)/p6
+    return ((64*K.pow(x,6))-(480*K.pow(x,4))+(720*K.pow(x,2))-120)/720
 get_custom_objects().update({'H_X_6': Activation(H_X_6)})
 
 
@@ -234,36 +220,30 @@ get_custom_objects().update({'H_X_6': Activation(H_X_6)})
 #Defining New Activation functions
 ############################################################################
 def L_X_1(x):
-    return (K.pow(x,1))/p1
+    return (K.pow(x,1))/1
 get_custom_objects().update({'L_X_1': Activation(L_X_1)})
 ############################################################################
 def L_X_2(x):
-    return ((3*K.pow(x,2))-1)/(2*p2)
+    return ((3*K.pow(x,2))-1)/(2*2)
 get_custom_objects().update({'L_X_2': Activation(L_X_2)})
 ############################################################################
 def L_X_3(x):
-    return ((5*K.pow(x,3))-(3*x))/(2*p3)
+    return ((5*K.pow(x,3))-(3*x))/(2*6)
 get_custom_objects().update({'L_X_3': Activation(L_X_3)})
 ############################################################################
 def L_X_4(x):
-    return ((35*K.pow(x,4))-(32*K.pow(x,2))+3)/(8*p4)
+    return ((35*K.pow(x,4))-(32*K.pow(x,2))+3)/(8*24)
 get_custom_objects().update({'L_X_4': Activation(L_X_4)})
 ############################################################################
 def L_X_5(x):
-    return ((63*K.pow(x,5))-(70*K.pow(x,3))+15*x)/(8*p5)
+    return ((63*K.pow(x,5))-(70*K.pow(x,3))+15*x)/(8*120)
 get_custom_objects().update({'L_X_5': Activation(L_X_5)})
 ############################################################################
 def L_X_6(x):
-    return  ((231*K.pow(x,6))-(315*K.pow(x,4))+(105*K.pow(x,2))-5)/(16*p6)
+    return  ((231*K.pow(x,6))-(315*K.pow(x,4))+(105*K.pow(x,2))-5)/(16*720)
 get_custom_objects().update({'L_X_6': Activation(L_X_6)})
 
 
-# ### Dense_Co is a custom Keras Layer which we develop to implement SWAG
-# 
-
-# In[11]:
-
-
 
 class Dense_Ch_a(Layer):
     def __init__(self, units,
